@@ -2,11 +2,8 @@ package Text::MatchedPosition;
 use strict;
 use warnings;
 use utf8;
-use Class::Accessor::Lite (
-    ro => [qw/text regex/],
-);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, $text, $regex) = @_;
@@ -24,6 +21,10 @@ sub new {
     bless $args, $class;
 }
 
+sub text { $_[0]->{text} }
+
+sub regex { $_[0]->{regex} }
+
 sub line {
     my $self = shift;
 
@@ -107,6 +108,14 @@ return the count of offset number. The beginning is C<1>;
 
 If regex is no match, C<offset> to be C<undef>.
 
+=head2 text
+
+getter for text lines
+
+=head2 regex
+
+getter for regex
+
 
 =head1 REPOSITORY
 
